@@ -120,8 +120,10 @@ where
     /// ordered by key range.
     ///
     /// The iterator element type is `(&'a RangeInclusive<K>, &'a V)`.
-    pub fn iter(&self) -> impl Iterator<Item = (&RangeInclusive<K>, &V)> {
-        self.btm.iter().map(|(by_start, v)| (&by_start.range, v))
+    pub fn iter(&self) -> Iter<'_, K, V> {
+        Iter {
+            inner: self.btm.iter(),
+        }
     }
 
     /// Insert a pair of key range and value into the map.
@@ -480,9 +482,46 @@ where
     }
 }
 
+/// An iterator over the entries of a `RangeInclusiveMap`, ordered by key range.
+///
+/// The iterator element type is `(&'a RangeInclusive<K>, &'a V)`.
+///
+/// This `struct` is created by the [`iter`] method on [`RangeInclusiveMap`]. See its
+/// documentation for more.
+///
+/// [`iter`]: RangeInclusiveMap::iter
+pub struct Iter<'a, K, V> {
+    inner: alloc::collections::btree_map::Iter<'a, RangeInclusiveStartWrapper<K>, V>,
+}
+
+impl<'a, K, V> Iterator for Iter<'a, K, V>
+where
+    K: 'a,
+    V: 'a,
+{
+    type Item = (&'a RangeInclusive<K>, &'a V);
+
+    fn next(&mut self) -> Option<(&'a RangeInclusive<K>, &'a V)> {
+        self.inner.next().map(|(by_start, v)| (&by_start.range, v))
+    }
+
+    fn size_hint(&self) -> (usize, Option<usize>) {
+        self.inner.size_hint()
+    }
+}
+
+/// An owning iterator over the entries of a `RangeInclusiveMap`, ordered by key range.
+///
+/// The iterator element type is `(RangeInclusive<K>, V)`.
+///
+/// This `struct` is created by the [`into_iter`] method on [`RangeInclusiveMap`]
+/// (provided by the `IntoIterator` trait). See its documentation for more.
+///
+/// [`into_iter`]: IntoIterator::into_iter
 pub struct IntoIter<K, V> {
     inner: alloc::collections::btree_map::IntoIter<RangeInclusiveStartWrapper<K>, V>,
 }
+
 impl<K, V> IntoIterator for RangeInclusiveMap<K, V> {
     type Item = (RangeInclusive<K>, V);
     type IntoIter = IntoIter<K, V>;
@@ -492,6 +531,7 @@ impl<K, V> IntoIterator for RangeInclusiveMap<K, V> {
         }
     }
 }
+
 impl<K, V> Iterator for IntoIter<K, V> {
     type Item = (RangeInclusive<K>, V);
     fn next(&mut self) -> Option<(RangeInclusive<K>, V)> {
@@ -610,6 +650,14 @@ where
     }
 }
 
+/// An iterator over all ranges not covered by a `RangeInclusiveMap`.
+///
+/// The iterator element type is `RangeInclusive<K>`.
+///
+/// This `struct` is created by the [`gaps`] method on [`RangeInclusiveMap`]. See its
+/// documentation for more.
+///
+/// [`gaps`]: RangeInclusiveMap::gaps
 pub struct Gaps<'a, K, V, StepFnsT> {
     /// Would be redundant, but we need an extra flag to
     /// avoid overflowing when dealing with inclusive ranges.
