@@ -82,8 +82,10 @@ where
     /// ordered by key range.
     ///
     /// The iterator element type is `(&'a Range<K>, &'a V)`.
-    pub fn iter(&self) -> impl Iterator<Item = (&Range<K>, &V)> {
-        self.btm.iter().map(|(by_start, v)| (&by_start.range, v))
+    pub fn iter(&self) -> Iter<'_, K, V> {
+        Iter {
+            inner: self.btm.iter(),
+        }
     }
 
     /// Insert a pair of key range and value into the map.
@@ -389,9 +391,46 @@ where
     }
 }
 
+/// An iterator over the entries of a `RangeMap`, ordered by key range.
+///
+/// The iterator element type is `(&'a Range<K>, &'a V)`.
+///
+/// This `struct` is created by the [`iter`] method on [`RangeMap`]. See its
+/// documentation for more.
+///
+/// [`iter`]: RangeMap::iter
+pub struct Iter<'a, K, V> {
+    inner: alloc::collections::btree_map::Iter<'a, RangeStartWrapper<K>, V>,
+}
+
+impl<'a, K, V> Iterator for Iter<'a, K, V>
+where
+    K: 'a,
+    V: 'a,
+{
+    type Item = (&'a Range<K>, &'a V);
+
+    fn next(&mut self) -> Option<(&'a Range<K>, &'a V)> {
+        self.inner.next().map(|(by_start, v)| (&by_start.range, v))
+    }
+
+    fn size_hint(&self) -> (usize, Option<usize>) {
+        self.inner.size_hint()
+    }
+}
+
+/// An owning iterator over the entries of a `RangeMap`, ordered by key range.
+///
+/// The iterator element type is `(Range<K>, V)`.
+///
+/// This `struct` is created by the [`into_iter`] method on [`RangeMap`]
+/// (provided by the `IntoIterator` trait). See its documentation for more.
+///
+/// [`into_iter`]: IntoIterator::into_iter
 pub struct IntoIter<K, V> {
     inner: alloc::collections::btree_map::IntoIter<RangeStartWrapper<K>, V>,
 }
+
 impl<K, V> IntoIterator for RangeMap<K, V> {
     type Item = (Range<K>, V);
     type IntoIter = IntoIter<K, V>;
@@ -401,6 +440,7 @@ impl<K, V> IntoIterator for RangeMap<K, V> {
         }
     }
 }
+
 impl<K, V> Iterator for IntoIter<K, V> {
     type Item = (Range<K>, V);
     fn next(&mut self) -> Option<(Range<K>, V)> {
@@ -519,6 +559,14 @@ where
     }
 }
 
+/// An iterator over all ranges not covered by a `RangeMap`.
+///
+/// The iterator element type is `Range<K>`.
+///
+/// This `struct` is created by the [`gaps`] method on [`RangeMap`]. See its
+/// documentation for more.
+///
+/// [`gaps`]: RangeMap::gaps
 pub struct Gaps<'a, K, V> {
     outer_range: &'a Range<K>,
     keys: core::iter::Peekable<alloc::collections::btree_map::Keys<'a, RangeStartWrapper<K>, V>>,
